@@ -28,6 +28,7 @@ from typing import TYPE_CHECKING, Any, Dict, List, Union
 import cloudpickle as pickle
 import yaml
 
+from .._shared_files import logger
 from .._shared_files.util_classes import RESULT_STATUS, Status
 from .utils import convert_to_lattice_function_call
 
@@ -35,6 +36,9 @@ if TYPE_CHECKING:
     from .._shared_files.util_classes import Status
     from .._workflow.lattice import Lattice
 
+app_log = logger.app_log
+log_stack_info = logger.log_stack_info
+
 
 class Result:
     """
@@ -369,7 +373,7 @@ Node Outputs
         self._lattice.transport_graph.set_node_value(node_id, "stdout", stdout)
         self._lattice.transport_graph.set_node_value(node_id, "stderr", stderr)
 
-    def save(self, directory: str = None) -> None:
+    def save(self, directory: str = None, write_source: bool = False) -> None:
         """
         Save the result object to a file.
 
@@ -404,7 +408,8 @@ Node Outputs
         with open(os.path.join(result_folder_path, "result_info.yaml"), "w") as f:
             yaml.dump(result_info, f)
 
-        self._write_dispatch_to_python_file()
+        if write_source:
+            self._write_dispatch_to_python_file()
 
     def _convert_to_electron_result(self) -> Any:
         """
